import Lottie from "react-lottie";
import { useRef } from "react";
import github from "assets/json/github.json";
import linkedin from "assets/json/linkedin.json";
import instagram from "assets/json/instagram.json";
import discord from "assets/json/discord.json";
import email from "assets/images/email.png";
import twitter from "assets/json/twitter.json";

const Footer = () => {
  const playAnimation = (ref: any) => {
    if (ref?.current) {
      ref.current.play();
    }
  };

  const contactLinks = [
    {
      href: "https://github.com/amirmoghi3",
      label: "Github",
      icon: github,
      path: "assets/json/github.json",
      ref: useRef(null),
    },
    {
      href: "https://www.linkedin.com/in/amirmoghi3/",
      label: "LinkedIn",
      icon: linkedin,
      path: "assets/json/linkedin.json",
      ref: useRef(null),
    },
    {
      href: "https://www.instagram.com/itsmoghi3/",
      label: "Instagram",
      icon: instagram,
      path: "assets/json/instagram.json",
      ref: useRef(null),
    },
    {
      href: "https://twitter.com/amirmoghi3",
      label: "Twitter",
      icon: twitter,
      path: "assets/json/twitter.json",
      ref: useRef(null),
    },
    {
      // email
      href: "mailto:siramirmoghi3@gmail.com",
      label: "Email",
      icon: email,
    },
    {
      //discord
      href: "https://discord.gg/FeECbW766J",
      label: "Discord",
      icon: discord,
      path: "assets/json/discord.json",
      ref: useRef(null),
    },
  ];

  return (
    <div className="fixed bottom-5  md:px-5 py-3  w-full">
      <div className="flex flex-col md:flex-row-reverse justify-between w-full">
        <div className="flex flex-row">
          {contactLinks.map((contactLink) => (
            <a
              onMouseEnter={() => playAnimation(contactLink.ref)}
              href={contactLink.href}
              target="_blank"
              key={contactLink.href}
              className="px-2 cursor-pointer"
              rel="noreferrer"
            >
              {contactLink.path ? (
                <div className="bg-secondary w-7 h-7 hover:bg-gold">
                  <div className="relative -top-2 -right-2">
                    <Lottie
                      ref={contactLink.ref}
                      options={{
                        animationData: contactLink.icon,
                        loop: false,
                        autoplay: true,
                      }}
                      height={20}
                      width={20}
                      title={contactLink.label}
                    />
                  </div>
                </div>
              ) : (
                <div className="bg-secondary w-7 h-7 hover:bg-gold">
                  <div className="relative -top-2 -right-3">
                    <img
                      src={contactLink.icon as string}
                      width={20}
                      height={20}
                      alt={contactLink.label}
                    />
                  </div>
                </div>
              )}
            </a>
          ))}
          <div className="px-2 cursor-pointer w-[20px] h-[20px]"></div>
        </div>
        <div className="container">
          <p className="text-secondary text-xs opacity-30 pl-1 md:pl-0 break-all">
            @2020 Amir Hossein Moghiseh - Version{" 0.2-beta"}
          </p>
        </div>
      </div>
    </div>
  );
};

export default Footer;
