import { Launch } from "@material-ui/icons";
type Props = {
  title: string;
  description: string;
  tags: string[];
  year?: string | number;
  url?: string;
  isLunched?: boolean;
  development: boolean;
  image?: string;
  time?: string;
};

const Journey = ({
  title,
  description,
  tags,
  year,
  url,
  isLunched,
  development,
  image,
  time,
}: Props) => {
  return (
    <div className="bg-dark-primary rounded-md flex flex-col p-3 mx-3 relative">
      <div className="flex justify-between">
        <h3 className="text-2xl font-bold text-gold rounded-lg px-1 py-2">
          {title}
          {isLunched && (
            <a href={url} target="_blank" rel="noreferrer" className="relative">
              <Launch fontSize="small" />
            </a>
          )}
        </h3>
        <div className="bg-white rounded-full w-16 h-16 flex flex-col justify-center items-center">
          <img src={image} width={30} height={30} alt={title} />
        </div>
      </div>
      <div className="flex justify-between">
        <p className="text-secondary opacity-80 text-sm text-left px-1 my-2">
          {description}
        </p>
      </div>

      <div className="flex flex-row flex-wrap ">
        {tags.map((tag, i) => (
          <p
            key={i}
            className="text-dark-primary bg-secondary rounded-md p-1 opacity-80 text-xs m-1"
          >
            {`#${tag}`}
          </p>
        ))}
      </div>
      {development && (
        <p className="text-secondary opacity-60 text-xs text-left px-1 mt-1 mb-0">
          Start From <strong className="opacity-80 text-sm">{year}</strong> To
          Now
        </p>
      )}
      {!development && (
        <p className="text-secondary opacity-60 text-xs text-left px-1 mt-1 mb-0">
          Built And Designed At{" "}
          <strong className="opacity-80 text-sm">{year}</strong>
        </p>
      )}
      <div>
        <img src={time} />
      </div>
    </div>
  );
};

export default Journey;
